@@ -7,8 +7,8 @@ from konoha.word_tokenizers.tokenizer import BaseTokenizer
 class WhitespaceTokenizer(BaseTokenizer):
     """Simple rule-based word tokenizer."""
 
-    def __init__(self) -> None:
-        super(WhitespaceTokenizer, self).__init__("whitespace")
+    def __init__(_) -> None:
+        super().__init__(name="whitespace")
 
-    def tokenize(self, text: str) -> List[Token]:
+    def tokenize(_, text: str) -> List[Token]:
         return [Token(surface=surface) for surface in text.split(" ")]
